==> applinks-basicauth-plugin-5.4.1-sources.jar: com/atlassian/applinks/basic/auth/BasicAuthRequestFactoryImpl.java <==
package com.atlassian.applinks.basic.auth;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.Map;

import com.atlassian.applinks.api.ApplicationLink;
import com.atlassian.applinks.api.ApplicationLinkRequest;
import com.atlassian.applinks.api.ApplicationLinkRequestFactory;
import com.atlassian.applinks.api.auth.types.BasicAuthenticationProvider;
import com.atlassian.applinks.core.auth.ApplicationLinkRequestAdaptor;
import com.atlassian.applinks.spi.auth.AuthenticationConfigurationManager;
import com.atlassian.sal.api.net.Request;
import com.atlassian.sal.api.net.RequestFactory;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * atlassian-plugin.xml excerpt:
 * {@code
 * <applinks-authentication-provider
 * class="com.atlassian.applinks.core.auth.basic.BasicAuthRequestFactoryImpl">
 * </applinks-authentication-provider>
 * }
 */
public class BasicAuthRequestFactoryImpl implements ApplicationLinkRequestFactory {
    public static final String USERNAME_KEY = "username";
    public static final String PASSWORD_KEY = "password";

    private final AuthenticationConfigurationManager authenticationConfigurationManager;
    private final ApplicationLink applicationLink;
    private final RequestFactory requestFactory;

    public BasicAuthRequestFactoryImpl(final AuthenticationConfigurationManager authenticationConfigurationManager,
                                       final ApplicationLink applicationLink, final RequestFactory requestFactory) {
        this.authenticationConfigurationManager = checkNotNull(authenticationConfigurationManager);
        this.applicationLink = checkNotNull(applicationLink);
        this.requestFactory = checkNotNull(requestFactory);
    }

    public ApplicationLinkRequest createRequest(final Request.MethodType methodType, final String url) {
        final Map<String, String> config = authenticationConfigurationManager
                .getConfiguration(applicationLink.getId(), BasicAuthenticationProvider.class);
        if (config == null) {
            throw new IllegalStateException(String.format(
                    "Basic HTTP Authentication is not configured for application link %s", applicationLink));
        }

        final URI uri;
        try {
            uri = new URI(url);
        } catch (URISyntaxException e) {
            throw new IllegalArgumentException("invalid url '" + url + "'", e);
        }

        return new ApplicationLinkRequestAdaptor(
                requestFactory.createRequest(methodType, url))
                .addBasicAuthentication(uri.getHost(), config.get(USERNAME_KEY), config.get(PASSWORD_KEY));
    }

    public URI getAuthorisationURI() {
        return null;
    }

    public URI getAuthorisationURI(final URI callback) {
        return null;
    }

}

==> applinks-basicauth-plugin-8.0.0-sources.jar: com/atlassian/applinks/basic/auth/BasicAuthRequestFactoryImpl.java <==
package com.atlassian.applinks.basic.auth;

import com.atlassian.applinks.api.ApplicationLink;
import com.atlassian.applinks.api.ApplicationLinkRequest;
import com.atlassian.applinks.api.ApplicationLinkRequestFactory;
import com.atlassian.applinks.api.auth.types.BasicAuthenticationProvider;
import com.atlassian.applinks.core.auth.ApplicationLinkRequestAdaptor;
import com.atlassian.applinks.spi.auth.AuthenticationConfigurationManager;
import com.atlassian.sal.api.net.Request;
import com.atlassian.sal.api.net.RequestFactory;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.Map;

import static java.util.Objects.requireNonNull;


/**
 * atlassian-plugin.xml excerpt:
 * {@code
 * <applinks-authentication-provider
 * class="com.atlassian.applinks.core.auth.basic.BasicAuthRequestFactoryImpl">
 * </applinks-authentication-provider>
 * }
 */
public class BasicAuthRequestFactoryImpl implements ApplicationLinkRequestFactory {
    public static final String USERNAME_KEY = "username";
    public static final String PASSWORD_KEY = "password";

    private final AuthenticationConfigurationManager authenticationConfigurationManager;
    private final ApplicationLink applicationLink;
    private final RequestFactory requestFactory;

    public BasicAuthRequestFactoryImpl(final AuthenticationConfigurationManager authenticationConfigurationManager,
                                       final ApplicationLink applicationLink, final RequestFactory requestFactory) {
        this.authenticationConfigurationManager = requireNonNull(authenticationConfigurationManager, "authenticationConfigurationManager can't be null");
        this.applicationLink = requireNonNull(applicationLink, "applicationLink can't be null");
        this.requestFactory = requireNonNull(requestFactory, "requestFactory can't be null");
    }

    public ApplicationLinkRequest createRequest(final Request.MethodType methodType, final String url) {
        final Map<String, String> config = authenticationConfigurationManager
                .getConfiguration(applicationLink.getId(), BasicAuthenticationProvider.class);
        if (config == null) {
            throw new IllegalStateException(String.format(
                    "Basic HTTP Authentication is not configured for application link %s", applicationLink));
        }

        final URI uri;
        try {
            uri = new URI(url);
        } catch (URISyntaxException e) {
            throw new IllegalArgumentException("invalid url '" + url + "'", e);
        }

        return new ApplicationLinkRequestAdaptor(
                requestFactory.createRequest(methodType, url))
                .addBasicAuthentication(uri.getHost(), config.get(USERNAME_KEY), config.get(PASSWORD_KEY));
    }

    public URI getAuthorisationURI() {
        return null;
    }

    public URI getAuthorisationURI(final URI callback) {
        return null;
    }

}
